summaryrefslogtreecommitdiff
path: root/types
diff options
context:
space:
mode:
Diffstat (limited to 'types')
-rw-r--r--types/protocol/protocol.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/types/protocol/protocol.go b/types/protocol/protocol.go
index 85b0733..4584066 100644
--- a/types/protocol/protocol.go
+++ b/types/protocol/protocol.go
@@ -11,8 +11,8 @@ const (
OpenVPN
// WireGuard indicates that the protocol is WireGuard
WireGuard
- // WireGuardTCP indicates that the protocol is WireGuard with a TCP proxy
- WireGuardTCP
+ // WireGuardProxy indicates that the protocol is WireGuard with proxyguard
+ WireGuardProxy
)
// New creates a new protocol type from a string